// EasySleep (PSoC4BLE)
//
// "at least BLE should be put to sleep at end of each CyBle_ProcessEvents() frame"
//    - old chinese proverb
//
// Created by speedycat
// 
//

#ifndef PSOC4BLE_EASYSLEEP_H
#define PSOC4BLE_EASYSLEEP_H
#include <project.h>
#include <stdint.h>
#include <stdbool.h>
#include "define.h"



// wakeup times taken from DfLPaEBLfA 2.2 table 2
typedef enum
{
    BLE_SLEEP,                    // try to sleep BLE, but not CPU.
                                  // BLE Sleep or Active
                                  // BLE wakeup time <= X s (fast) // FIXME

    BLE_DEEPSLEEP,                // try to sleep BLE, but not CPU.
                                  // BLE DeepSleep or Sleep or Active
                                  // BLE wakeup time <= XX s // FIXME 0.002

    BLE_SLEEP_CPU_SLEEP,          // try to sleep BLE, try to sleep CPU.
                                  // BLE Sleep or Active
                                  // CPU Sleep or Active
                                  // BLE wakeup time <= X s (fast) // FIXME
                                  // CPU wakeup time <= 0 s (fast (??)) 

    BLE_DEEPSLEEP_CPU_SLEEP,      // try to sleep BLE, try to sleep CPU. 
                                  // BLE DeepSleep or Sleep or Active
                                  // BLE wakeup time <= XX s // FIXME 0.002
                                  // CPU wakeup time <= 0 s (fast (??)) // FIXME

    BLE_DEEPSLEEP_CPU_DEEPSLEEP   // try to sleep BLE, try to sleep CPU. 
                                  // BLE DeepSleep or Sleep or Active
                                  // CPU DeepSleep or Sleep or Active
                                  // BLE wakeup time <= XX s // FIXME 0.002
                                  // CPU wakeup time <= 0.000025 s

} BLESleepT;


////////////////////////////////////////////////////////////////////////////////
// 


//
// try to sleep BLE (DeepSleep or Sleep), and also CPU if requested
// CPU may actually sleep but not BLE. 
// the actual blocking time will be a little longer than the value given above.
//
void sleep_ble(BLESleepT );

//
// wait for BLE to wake up
//
void wakeup_ble();

//
// set callbacks for CPU sleep/wakup, 
// for example put components other than BLE to sleep.
// these callbacks are _not_ allowed to enable interrupts!
//
void cpu_sleep_callbacks(void (*sleep)(bool ), void (*deepsleep)(bool ));


#endif


