/*******************************************************************************
* File Name: AmpBuf.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "AmpBuf.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        AmpBuf_PC =   (AmpBuf_PC & \
                                (uint32)(~(uint32)(AmpBuf_DRIVE_MODE_IND_MASK << (AmpBuf_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (AmpBuf_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: AmpBuf_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void AmpBuf_Write(uint8 value) 
{
    uint8 drVal = (uint8)(AmpBuf_DR & (uint8)(~AmpBuf_MASK));
    drVal = (drVal | ((uint8)(value << AmpBuf_SHIFT) & AmpBuf_MASK));
    AmpBuf_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: AmpBuf_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  AmpBuf_DM_STRONG     Strong Drive 
*  AmpBuf_DM_OD_HI      Open Drain, Drives High 
*  AmpBuf_DM_OD_LO      Open Drain, Drives Low 
*  AmpBuf_DM_RES_UP     Resistive Pull Up 
*  AmpBuf_DM_RES_DWN    Resistive Pull Down 
*  AmpBuf_DM_RES_UPDWN  Resistive Pull Up/Down 
*  AmpBuf_DM_DIG_HIZ    High Impedance Digital 
*  AmpBuf_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void AmpBuf_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(AmpBuf__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: AmpBuf_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro AmpBuf_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 AmpBuf_Read(void) 
{
    return (uint8)((AmpBuf_PS & AmpBuf_MASK) >> AmpBuf_SHIFT);
}


/*******************************************************************************
* Function Name: AmpBuf_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 AmpBuf_ReadDataReg(void) 
{
    return (uint8)((AmpBuf_DR & AmpBuf_MASK) >> AmpBuf_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(AmpBuf_INTSTAT) 

    /*******************************************************************************
    * Function Name: AmpBuf_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 AmpBuf_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(AmpBuf_INTSTAT & AmpBuf_MASK);
		AmpBuf_INTSTAT = maskedStatus;
        return maskedStatus >> AmpBuf_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
