/*******************************************************************************
* File Name: AmpBuf23.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "AmpBuf23.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        AmpBuf23_PC =   (AmpBuf23_PC & \
                                (uint32)(~(uint32)(AmpBuf23_DRIVE_MODE_IND_MASK << (AmpBuf23_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (AmpBuf23_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: AmpBuf23_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void AmpBuf23_Write(uint8 value) 
{
    uint8 drVal = (uint8)(AmpBuf23_DR & (uint8)(~AmpBuf23_MASK));
    drVal = (drVal | ((uint8)(value << AmpBuf23_SHIFT) & AmpBuf23_MASK));
    AmpBuf23_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: AmpBuf23_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  AmpBuf23_DM_STRONG     Strong Drive 
*  AmpBuf23_DM_OD_HI      Open Drain, Drives High 
*  AmpBuf23_DM_OD_LO      Open Drain, Drives Low 
*  AmpBuf23_DM_RES_UP     Resistive Pull Up 
*  AmpBuf23_DM_RES_DWN    Resistive Pull Down 
*  AmpBuf23_DM_RES_UPDWN  Resistive Pull Up/Down 
*  AmpBuf23_DM_DIG_HIZ    High Impedance Digital 
*  AmpBuf23_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void AmpBuf23_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(AmpBuf23__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: AmpBuf23_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro AmpBuf23_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 AmpBuf23_Read(void) 
{
    return (uint8)((AmpBuf23_PS & AmpBuf23_MASK) >> AmpBuf23_SHIFT);
}


/*******************************************************************************
* Function Name: AmpBuf23_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 AmpBuf23_ReadDataReg(void) 
{
    return (uint8)((AmpBuf23_DR & AmpBuf23_MASK) >> AmpBuf23_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(AmpBuf23_INTSTAT) 

    /*******************************************************************************
    * Function Name: AmpBuf23_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 AmpBuf23_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(AmpBuf23_INTSTAT & AmpBuf23_MASK);
		AmpBuf23_INTSTAT = maskedStatus;
        return maskedStatus >> AmpBuf23_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
