/*******************************************************************************
* File Name: AmpP13.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "AmpP13.h"

static AmpP13_BACKUP_STRUCT  AmpP13_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: AmpP13_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function must be called for SIO and USBIO
*  pins. It is not essential if using GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet AmpP13_SUT.c usage_AmpP13_Sleep_Wakeup
*******************************************************************************/
void AmpP13_Sleep(void)
{
    #if defined(AmpP13__PC)
        AmpP13_backup.pcState = AmpP13_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            AmpP13_backup.usbState = AmpP13_CR1_REG;
            AmpP13_USB_POWER_REG |= AmpP13_USBIO_ENTER_SLEEP;
            AmpP13_CR1_REG &= AmpP13_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(AmpP13__SIO)
        AmpP13_backup.sioState = AmpP13_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        AmpP13_SIO_REG &= (uint32)(~AmpP13_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: AmpP13_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep().
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to AmpP13_Sleep() for an example usage.
*******************************************************************************/
void AmpP13_Wakeup(void)
{
    #if defined(AmpP13__PC)
        AmpP13_PC = AmpP13_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            AmpP13_USB_POWER_REG &= AmpP13_USBIO_EXIT_SLEEP_PH1;
            AmpP13_CR1_REG = AmpP13_backup.usbState;
            AmpP13_USB_POWER_REG &= AmpP13_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(AmpP13__SIO)
        AmpP13_SIO_REG = AmpP13_backup.sioState;
    #endif
}


/* [] END OF FILE */
