/*******************************************************************************
* File Name: AmpRef.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "AmpRef.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        AmpRef_PC =   (AmpRef_PC & \
                                (uint32)(~(uint32)(AmpRef_DRIVE_MODE_IND_MASK << (AmpRef_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (AmpRef_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: AmpRef_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void AmpRef_Write(uint8 value) 
{
    uint8 drVal = (uint8)(AmpRef_DR & (uint8)(~AmpRef_MASK));
    drVal = (drVal | ((uint8)(value << AmpRef_SHIFT) & AmpRef_MASK));
    AmpRef_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: AmpRef_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  AmpRef_DM_STRONG     Strong Drive 
*  AmpRef_DM_OD_HI      Open Drain, Drives High 
*  AmpRef_DM_OD_LO      Open Drain, Drives Low 
*  AmpRef_DM_RES_UP     Resistive Pull Up 
*  AmpRef_DM_RES_DWN    Resistive Pull Down 
*  AmpRef_DM_RES_UPDWN  Resistive Pull Up/Down 
*  AmpRef_DM_DIG_HIZ    High Impedance Digital 
*  AmpRef_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void AmpRef_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(AmpRef__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: AmpRef_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro AmpRef_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 AmpRef_Read(void) 
{
    return (uint8)((AmpRef_PS & AmpRef_MASK) >> AmpRef_SHIFT);
}


/*******************************************************************************
* Function Name: AmpRef_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 AmpRef_ReadDataReg(void) 
{
    return (uint8)((AmpRef_DR & AmpRef_MASK) >> AmpRef_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(AmpRef_INTSTAT) 

    /*******************************************************************************
    * Function Name: AmpRef_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 AmpRef_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(AmpRef_INTSTAT & AmpRef_MASK);
		AmpRef_INTSTAT = maskedStatus;
        return maskedStatus >> AmpRef_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
