/*******************************************************************************
* File Name: BattLevel33.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "BattLevel33.h"

static BattLevel33_BACKUP_STRUCT  BattLevel33_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: BattLevel33_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function must be called for SIO and USBIO
*  pins. It is not essential if using GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet BattLevel33_SUT.c usage_BattLevel33_Sleep_Wakeup
*******************************************************************************/
void BattLevel33_Sleep(void)
{
    #if defined(BattLevel33__PC)
        BattLevel33_backup.pcState = BattLevel33_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            BattLevel33_backup.usbState = BattLevel33_CR1_REG;
            BattLevel33_USB_POWER_REG |= BattLevel33_USBIO_ENTER_SLEEP;
            BattLevel33_CR1_REG &= BattLevel33_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(BattLevel33__SIO)
        BattLevel33_backup.sioState = BattLevel33_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        BattLevel33_SIO_REG &= (uint32)(~BattLevel33_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: BattLevel33_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep().
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to BattLevel33_Sleep() for an example usage.
*******************************************************************************/
void BattLevel33_Wakeup(void)
{
    #if defined(BattLevel33__PC)
        BattLevel33_PC = BattLevel33_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            BattLevel33_USB_POWER_REG &= BattLevel33_USBIO_EXIT_SLEEP_PH1;
            BattLevel33_CR1_REG = BattLevel33_backup.usbState;
            BattLevel33_USB_POWER_REG &= BattLevel33_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(BattLevel33__SIO)
        BattLevel33_SIO_REG = BattLevel33_backup.sioState;
    #endif
}


/* [] END OF FILE */
