/*******************************************************************************
* File Name: FilterP31.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "FilterP31.h"

static FilterP31_BACKUP_STRUCT  FilterP31_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: FilterP31_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function must be called for SIO and USBIO
*  pins. It is not essential if using GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet FilterP31_SUT.c usage_FilterP31_Sleep_Wakeup
*******************************************************************************/
void FilterP31_Sleep(void)
{
    #if defined(FilterP31__PC)
        FilterP31_backup.pcState = FilterP31_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            FilterP31_backup.usbState = FilterP31_CR1_REG;
            FilterP31_USB_POWER_REG |= FilterP31_USBIO_ENTER_SLEEP;
            FilterP31_CR1_REG &= FilterP31_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(FilterP31__SIO)
        FilterP31_backup.sioState = FilterP31_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        FilterP31_SIO_REG &= (uint32)(~FilterP31_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: FilterP31_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep().
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to FilterP31_Sleep() for an example usage.
*******************************************************************************/
void FilterP31_Wakeup(void)
{
    #if defined(FilterP31__PC)
        FilterP31_PC = FilterP31_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            FilterP31_USB_POWER_REG &= FilterP31_USBIO_EXIT_SLEEP_PH1;
            FilterP31_CR1_REG = FilterP31_backup.usbState;
            FilterP31_USB_POWER_REG &= FilterP31_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(FilterP31__SIO)
        FilterP31_SIO_REG = FilterP31_backup.sioState;
    #endif
}


/* [] END OF FILE */
