/*******************************************************************************
* File Name: LEDLCSB21.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "LEDLCSB21.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        LEDLCSB21_PC =   (LEDLCSB21_PC & \
                                (uint32)(~(uint32)(LEDLCSB21_DRIVE_MODE_IND_MASK << (LEDLCSB21_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (LEDLCSB21_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: LEDLCSB21_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void LEDLCSB21_Write(uint8 value) 
{
    uint8 drVal = (uint8)(LEDLCSB21_DR & (uint8)(~LEDLCSB21_MASK));
    drVal = (drVal | ((uint8)(value << LEDLCSB21_SHIFT) & LEDLCSB21_MASK));
    LEDLCSB21_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: LEDLCSB21_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  LEDLCSB21_DM_STRONG     Strong Drive 
*  LEDLCSB21_DM_OD_HI      Open Drain, Drives High 
*  LEDLCSB21_DM_OD_LO      Open Drain, Drives Low 
*  LEDLCSB21_DM_RES_UP     Resistive Pull Up 
*  LEDLCSB21_DM_RES_DWN    Resistive Pull Down 
*  LEDLCSB21_DM_RES_UPDWN  Resistive Pull Up/Down 
*  LEDLCSB21_DM_DIG_HIZ    High Impedance Digital 
*  LEDLCSB21_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void LEDLCSB21_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(LEDLCSB21__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: LEDLCSB21_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro LEDLCSB21_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 LEDLCSB21_Read(void) 
{
    return (uint8)((LEDLCSB21_PS & LEDLCSB21_MASK) >> LEDLCSB21_SHIFT);
}


/*******************************************************************************
* Function Name: LEDLCSB21_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 LEDLCSB21_ReadDataReg(void) 
{
    return (uint8)((LEDLCSB21_DR & LEDLCSB21_MASK) >> LEDLCSB21_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(LEDLCSB21_INTSTAT) 

    /*******************************************************************************
    * Function Name: LEDLCSB21_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 LEDLCSB21_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(LEDLCSB21_INTSTAT & LEDLCSB21_MASK);
		LEDLCSB21_INTSTAT = maskedStatus;
        return maskedStatus >> LEDLCSB21_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
