/*******************************************************************************
* File Name: LREG01.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_LREG01_H) /* Pins LREG01_H */
#define CY_PINS_LREG01_H

#include "cytypes.h"
#include "cyfitter.h"
#include "LREG01_aliases.h"


/***************************************
*     Data Struct Definitions
***************************************/

/**
* \addtogroup group_structures
* @{
*/
    
/* Structure for sleep mode support */
typedef struct
{
    uint32 pcState; /**< State of the port control register */
    uint32 sioState; /**< State of the SIO configuration */
    uint32 usbState; /**< State of the USBIO regulator */
} LREG01_BACKUP_STRUCT;

/** @} structures */


/***************************************
*        Function Prototypes             
***************************************/
/**
* \addtogroup group_general
* @{
*/
uint8   LREG01_Read(void);
void    LREG01_Write(uint8 value);
uint8   LREG01_ReadDataReg(void);
#if defined(LREG01__PC) || (CY_PSOC4_4200L) 
    void    LREG01_SetDriveMode(uint8 mode);
#endif
void    LREG01_SetInterruptMode(uint16 position, uint16 mode);
uint8   LREG01_ClearInterrupt(void);
/** @} general */

/**
* \addtogroup group_power
* @{
*/
void LREG01_Sleep(void); 
void LREG01_Wakeup(void);
/** @} power */


/***************************************
*           API Constants        
***************************************/
#if defined(LREG01__PC) || (CY_PSOC4_4200L) 
    /* Drive Modes */
    #define LREG01_DRIVE_MODE_BITS        (3)
    #define LREG01_DRIVE_MODE_IND_MASK    (0xFFFFFFFFu >> (32 - LREG01_DRIVE_MODE_BITS))

    /**
    * \addtogroup group_constants
    * @{
    */
        /** \addtogroup driveMode Drive mode constants
         * \brief Constants to be passed as "mode" parameter in the LREG01_SetDriveMode() function.
         *  @{
         */
        #define LREG01_DM_ALG_HIZ         (0x00u) /**< \brief High Impedance Analog   */
        #define LREG01_DM_DIG_HIZ         (0x01u) /**< \brief High Impedance Digital  */
        #define LREG01_DM_RES_UP          (0x02u) /**< \brief Resistive Pull Up       */
        #define LREG01_DM_RES_DWN         (0x03u) /**< \brief Resistive Pull Down     */
        #define LREG01_DM_OD_LO           (0x04u) /**< \brief Open Drain, Drives Low  */
        #define LREG01_DM_OD_HI           (0x05u) /**< \brief Open Drain, Drives High */
        #define LREG01_DM_STRONG          (0x06u) /**< \brief Strong Drive            */
        #define LREG01_DM_RES_UPDWN       (0x07u) /**< \brief Resistive Pull Up/Down  */
        /** @} driveMode */
    /** @} group_constants */
#endif

/* Digital Port Constants */
#define LREG01_MASK               LREG01__MASK
#define LREG01_SHIFT              LREG01__SHIFT
#define LREG01_WIDTH              1u

/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in LREG01_SetInterruptMode() function.
     *  @{
     */
        #define LREG01_INTR_NONE      ((uint16)(0x0000u)) /**< \brief Disabled             */
        #define LREG01_INTR_RISING    ((uint16)(0x5555u)) /**< \brief Rising edge trigger  */
        #define LREG01_INTR_FALLING   ((uint16)(0xaaaau)) /**< \brief Falling edge trigger */
        #define LREG01_INTR_BOTH      ((uint16)(0xffffu)) /**< \brief Both edge trigger    */
    /** @} intrMode */
/** @} group_constants */

/* SIO LPM definition */
#if defined(LREG01__SIO)
    #define LREG01_SIO_LPM_MASK       (0x03u)
#endif

/* USBIO definitions */
#if !defined(LREG01__PC) && (CY_PSOC4_4200L)
    #define LREG01_USBIO_ENABLE               ((uint32)0x80000000u)
    #define LREG01_USBIO_DISABLE              ((uint32)(~LREG01_USBIO_ENABLE))
    #define LREG01_USBIO_SUSPEND_SHIFT        CYFLD_USBDEVv2_USB_SUSPEND__OFFSET
    #define LREG01_USBIO_SUSPEND_DEL_SHIFT    CYFLD_USBDEVv2_USB_SUSPEND_DEL__OFFSET
    #define LREG01_USBIO_ENTER_SLEEP          ((uint32)((1u << LREG01_USBIO_SUSPEND_SHIFT) \
                                                        | (1u << LREG01_USBIO_SUSPEND_DEL_SHIFT)))
    #define LREG01_USBIO_EXIT_SLEEP_PH1       ((uint32)~((uint32)(1u << LREG01_USBIO_SUSPEND_SHIFT)))
    #define LREG01_USBIO_EXIT_SLEEP_PH2       ((uint32)~((uint32)(1u << LREG01_USBIO_SUSPEND_DEL_SHIFT)))
    #define LREG01_USBIO_CR1_OFF              ((uint32)0xfffffffeu)
#endif


/***************************************
*             Registers        
***************************************/
/* Main Port Registers */
#if defined(LREG01__PC)
    /* Port Configuration */
    #define LREG01_PC                 (* (reg32 *) LREG01__PC)
#endif
/* Pin State */
#define LREG01_PS                     (* (reg32 *) LREG01__PS)
/* Data Register */
#define LREG01_DR                     (* (reg32 *) LREG01__DR)
/* Input Buffer Disable Override */
#define LREG01_INP_DIS                (* (reg32 *) LREG01__PC2)

/* Interrupt configuration Registers */
#define LREG01_INTCFG                 (* (reg32 *) LREG01__INTCFG)
#define LREG01_INTSTAT                (* (reg32 *) LREG01__INTSTAT)

/* "Interrupt cause" register for Combined Port Interrupt (AllPortInt) in GSRef component */
#if defined (CYREG_GPIO_INTR_CAUSE)
    #define LREG01_INTR_CAUSE         (* (reg32 *) CYREG_GPIO_INTR_CAUSE)
#endif

/* SIO register */
#if defined(LREG01__SIO)
    #define LREG01_SIO_REG            (* (reg32 *) LREG01__SIO)
#endif /* (LREG01__SIO_CFG) */

/* USBIO registers */
#if !defined(LREG01__PC) && (CY_PSOC4_4200L)
    #define LREG01_USB_POWER_REG       (* (reg32 *) CYREG_USBDEVv2_USB_POWER_CTRL)
    #define LREG01_CR1_REG             (* (reg32 *) CYREG_USBDEVv2_CR1)
    #define LREG01_USBIO_CTRL_REG      (* (reg32 *) CYREG_USBDEVv2_USB_USBIO_CTRL)
#endif    
    
    
/***************************************
* The following code is DEPRECATED and 
* must not be used in new designs.
***************************************/
/**
* \addtogroup group_deprecated
* @{
*/
#define LREG01_DRIVE_MODE_SHIFT       (0x00u)
#define LREG01_DRIVE_MODE_MASK        (0x07u << LREG01_DRIVE_MODE_SHIFT)
/** @} deprecated */

#endif /* End Pins LREG01_H */


/* [] END OF FILE */
