/*******************************************************************************
* File Name: LREG01.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "LREG01.h"

static LREG01_BACKUP_STRUCT  LREG01_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: LREG01_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function must be called for SIO and USBIO
*  pins. It is not essential if using GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet LREG01_SUT.c usage_LREG01_Sleep_Wakeup
*******************************************************************************/
void LREG01_Sleep(void)
{
    #if defined(LREG01__PC)
        LREG01_backup.pcState = LREG01_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            LREG01_backup.usbState = LREG01_CR1_REG;
            LREG01_USB_POWER_REG |= LREG01_USBIO_ENTER_SLEEP;
            LREG01_CR1_REG &= LREG01_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(LREG01__SIO)
        LREG01_backup.sioState = LREG01_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        LREG01_SIO_REG &= (uint32)(~LREG01_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: LREG01_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep().
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to LREG01_Sleep() for an example usage.
*******************************************************************************/
void LREG01_Wakeup(void)
{
    #if defined(LREG01__PC)
        LREG01_PC = LREG01_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            LREG01_USB_POWER_REG &= LREG01_USBIO_EXIT_SLEEP_PH1;
            LREG01_CR1_REG = LREG01_backup.usbState;
            LREG01_USB_POWER_REG &= LREG01_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(LREG01__SIO)
        LREG01_SIO_REG = LREG01_backup.sioState;
    #endif
}


/* [] END OF FILE */
