/*******************************************************************************
* File Name: NegBias.h
* Version 1.20
*
* Description:
*  This file contains the function prototypes and constants used in
*  the Opamp (Analog Buffer) Component.
*
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_OPAMP_NegBias_H)
#define CY_OPAMP_NegBias_H

#include "cytypes.h"
#include "cyfitter.h"


/***************************************
*       Type Definitions
***************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} NegBias_BACKUP_STRUCT;


/**************************************
*        Function Prototypes
**************************************/
void NegBias_Init(void);
void NegBias_Enable(void);
void NegBias_Start(void);
void NegBias_Stop(void);
void NegBias_SetPower(uint32 power);
void NegBias_PumpControl(uint32 onOff);
void NegBias_Sleep(void);
void NegBias_Wakeup(void);
void NegBias_SaveConfig(void);
void NegBias_RestoreConfig(void);


/**************************************
*           API Constants
**************************************/

/* Parameters for SetPower() function */
#define NegBias_LOW_POWER      (1u)
#define NegBias_MED_POWER      (2u)
#define NegBias_HIGH_POWER     (3u)


/* Parameters for PumpControl() function */
#define NegBias_PUMP_ON        (1u)
#define NegBias_PUMP_OFF       (0u)


/***************************************
*   Initial Parameter Constants
****************************************/

#define NegBias_OUTPUT_CURRENT         (1u)
#define NegBias_POWER                  (1u)
#define NegBias_MODE                   (0u)
#define NegBias_OA_COMP_TRIM_VALUE     (3u)
#define NegBias_DEEPSLEEP_SUPPORT      (0u)


/***************************************
*    Variables with External Linkage
***************************************/

extern uint8  NegBias_initVar;


/**************************************
*             Registers
**************************************/

#ifdef CYIPBLOCK_m0s8pass4b_VERSION
    #define NegBias_CTB_CTRL_REG       (*(reg32 *) NegBias_cy_psoc4_abuf__CTB_CTB_CTRL)
    #define NegBias_CTB_CTRL_PTR       ( (reg32 *) NegBias_cy_psoc4_abuf__CTB_CTB_CTRL)
#else
    #define NegBias_CTB_CTRL_REG       (*(reg32 *) NegBias_cy_psoc4_abuf__CTBM_CTB_CTRL)
    #define NegBias_CTB_CTRL_PTR       ( (reg32 *) NegBias_cy_psoc4_abuf__CTBM_CTB_CTRL)
#endif /* CYIPBLOCK_m0s8pass4b_VERSION */

#define NegBias_OA_RES_CTRL_REG    (*(reg32 *) NegBias_cy_psoc4_abuf__OA_RES_CTRL)
#define NegBias_OA_RES_CTRL_PTR    ( (reg32 *) NegBias_cy_psoc4_abuf__OA_RES_CTRL)
#define NegBias_OA_COMP_TRIM_REG   (*(reg32 *) NegBias_cy_psoc4_abuf__OA_COMP_TRIM)
#define NegBias_OA_COMP_TRIM_PTR   ( (reg32 *) NegBias_cy_psoc4_abuf__OA_COMP_TRIM)


/***************************************
*        Registers Constants
***************************************/

/* NegBias_CTB_CTRL_REG */
#define NegBias_CTB_CTRL_DEEPSLEEP_ON_SHIFT    (30u)   /* [30] Selects behavior CTB IP in the DeepSleep power mode */
#define NegBias_CTB_CTRL_ENABLED_SHIFT         (31u)   /* [31] Enable of the CTB IP */


#define NegBias_CTB_CTRL_DEEPSLEEP_ON          ((uint32) 0x01u << NegBias_CTB_CTRL_DEEPSLEEP_ON_SHIFT)
#define NegBias_CTB_CTRL_ENABLED               ((uint32) 0x01u << NegBias_CTB_CTRL_ENABLED_SHIFT)


/* NegBias_OA_RES_CTRL_REG */
#define NegBias_OA_PWR_MODE_SHIFT          (0u)    /* [1:0]    Power level */
#define NegBias_OA_DRIVE_STR_SEL_SHIFT     (2u)    /* [2]      Opamp output strenght select: 0 - 1x, 1 - 10x */
#define NegBias_OA_COMP_EN_SHIFT           (4u)    /* [4]      CTB IP mode: 0 - Opamp, 1 - Comparator  */
#define NegBias_OA_PUMP_EN_SHIFT           (11u)   /* [11]     Pump enable */


#define NegBias_OA_PWR_MODE                ((uint32) 0x02u << NegBias_OA_PWR_MODE_SHIFT)
#define NegBias_OA_PWR_MODE_MASK           ((uint32) 0x03u << NegBias_OA_PWR_MODE_SHIFT)
#define NegBias_OA_DRIVE_STR_SEL_1X        ((uint32) 0x00u << NegBias_OA_DRIVE_STR_SEL_SHIFT)
#define NegBias_OA_DRIVE_STR_SEL_10X       ((uint32) 0x01u << NegBias_OA_DRIVE_STR_SEL_SHIFT)
#define NegBias_OA_DRIVE_STR_SEL_MASK      ((uint32) 0x01u << NegBias_OA_DRIVE_STR_SEL_SHIFT)
#define NegBias_OA_COMP_EN                 ((uint32) 0x00u << NegBias_OA_COMP_EN_SHIFT)
#define NegBias_OA_PUMP_EN                 ((uint32) 0x01u << NegBias_OA_PUMP_EN_SHIFT)


/***************************************
*       Init Macros Definitions
***************************************/

#define NegBias_GET_DEEPSLEEP_ON(deepSleep)    ((0u != (deepSleep)) ? (NegBias_CTB_CTRL_DEEPSLEEP_ON) : (0u))
#define NegBias_GET_OA_DRIVE_STR(current)      ((0u != (current)) ? (NegBias_OA_DRIVE_STR_SEL_10X) : \
                                                                             (NegBias_OA_DRIVE_STR_SEL_1X))
#define NegBias_GET_OA_PWR_MODE(mode)          ((mode) & NegBias_OA_PWR_MODE_MASK)
#define NegBias_CHECK_PWR_MODE_OFF             (0u != (NegBias_OA_RES_CTRL_REG & \
                                                                NegBias_OA_PWR_MODE_MASK))

/* Returns true if component available in Deep Sleep power mode*/ 
#define NegBias_CHECK_DEEPSLEEP_SUPPORT        (0u != NegBias_DEEPSLEEP_SUPPORT) 

#define NegBias_DEFAULT_CTB_CTRL (NegBias_GET_DEEPSLEEP_ON(NegBias_DEEPSLEEP_SUPPORT) | \
                                           NegBias_CTB_CTRL_ENABLED)

#define NegBias_DEFAULT_OA_RES_CTRL (NegBias_OA_COMP_EN | \
                                              NegBias_GET_OA_DRIVE_STR(NegBias_OUTPUT_CURRENT))

#define NegBias_DEFAULT_OA_COMP_TRIM_REG (NegBias_OA_COMP_TRIM_VALUE)


/***************************************
* The following code is DEPRECATED and 
* should not be used in new projects.
***************************************/

#define NegBias_LOWPOWER                   (NegBias_LOW_POWER)
#define NegBias_MEDPOWER                   (NegBias_MED_POWER)
#define NegBias_HIGHPOWER                  (NegBias_HIGH_POWER)

/* PUMP ON/OFF defines */
#define NegBias_PUMPON                     (NegBias_PUMP_ON)
#define NegBias_PUMPOFF                    (NegBias_PUMP_OFF)

#define NegBias_OA_CTRL                    (NegBias_CTB_CTRL_REG)
#define NegBias_OA_RES_CTRL                (NegBias_OA_RES_CTRL_REG)

/* Bit Field  OA_CTRL */
#define NegBias_OA_CTB_EN_SHIFT            (NegBias_CTB_CTRL_ENABLED_SHIFT)
#define NegBias_OA_PUMP_CTRL_SHIFT         (NegBias_OA_PUMP_EN_SHIFT)
#define NegBias_OA_PUMP_EN_MASK            (0x800u)
#define NegBias_PUMP_PROTECT_MASK          (1u)


#endif    /* CY_OPAMP_NegBias_H */


/* [] END OF FILE */
