/*******************************************************************************
* File Name: NegBiasPlus.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "NegBiasPlus.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        NegBiasPlus_PC =   (NegBiasPlus_PC & \
                                (uint32)(~(uint32)(NegBiasPlus_DRIVE_MODE_IND_MASK << (NegBiasPlus_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (NegBiasPlus_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: NegBiasPlus_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void NegBiasPlus_Write(uint8 value) 
{
    uint8 drVal = (uint8)(NegBiasPlus_DR & (uint8)(~NegBiasPlus_MASK));
    drVal = (drVal | ((uint8)(value << NegBiasPlus_SHIFT) & NegBiasPlus_MASK));
    NegBiasPlus_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: NegBiasPlus_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  NegBiasPlus_DM_STRONG     Strong Drive 
*  NegBiasPlus_DM_OD_HI      Open Drain, Drives High 
*  NegBiasPlus_DM_OD_LO      Open Drain, Drives Low 
*  NegBiasPlus_DM_RES_UP     Resistive Pull Up 
*  NegBiasPlus_DM_RES_DWN    Resistive Pull Down 
*  NegBiasPlus_DM_RES_UPDWN  Resistive Pull Up/Down 
*  NegBiasPlus_DM_DIG_HIZ    High Impedance Digital 
*  NegBiasPlus_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void NegBiasPlus_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(NegBiasPlus__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: NegBiasPlus_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro NegBiasPlus_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 NegBiasPlus_Read(void) 
{
    return (uint8)((NegBiasPlus_PS & NegBiasPlus_MASK) >> NegBiasPlus_SHIFT);
}


/*******************************************************************************
* Function Name: NegBiasPlus_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 NegBiasPlus_ReadDataReg(void) 
{
    return (uint8)((NegBiasPlus_DR & NegBiasPlus_MASK) >> NegBiasPlus_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(NegBiasPlus_INTSTAT) 

    /*******************************************************************************
    * Function Name: NegBiasPlus_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 NegBiasPlus_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(NegBiasPlus_INTSTAT & NegBiasPlus_MASK);
		NegBiasPlus_INTSTAT = maskedStatus;
        return maskedStatus >> NegBiasPlus_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
