/*******************************************************************************
* File Name: PosADC.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PosADC.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        PosADC_PC =   (PosADC_PC & \
                                (uint32)(~(uint32)(PosADC_DRIVE_MODE_IND_MASK << (PosADC_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (PosADC_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: PosADC_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void PosADC_Write(uint8 value) 
{
    uint8 drVal = (uint8)(PosADC_DR & (uint8)(~PosADC_MASK));
    drVal = (drVal | ((uint8)(value << PosADC_SHIFT) & PosADC_MASK));
    PosADC_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: PosADC_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  PosADC_DM_STRONG     Strong Drive 
*  PosADC_DM_OD_HI      Open Drain, Drives High 
*  PosADC_DM_OD_LO      Open Drain, Drives Low 
*  PosADC_DM_RES_UP     Resistive Pull Up 
*  PosADC_DM_RES_DWN    Resistive Pull Down 
*  PosADC_DM_RES_UPDWN  Resistive Pull Up/Down 
*  PosADC_DM_DIG_HIZ    High Impedance Digital 
*  PosADC_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void PosADC_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(PosADC__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: PosADC_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PosADC_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PosADC_Read(void) 
{
    return (uint8)((PosADC_PS & PosADC_MASK) >> PosADC_SHIFT);
}


/*******************************************************************************
* Function Name: PosADC_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PosADC_ReadDataReg(void) 
{
    return (uint8)((PosADC_DR & PosADC_MASK) >> PosADC_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PosADC_INTSTAT) 

    /*******************************************************************************
    * Function Name: PosADC_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PosADC_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(PosADC_INTSTAT & PosADC_MASK);
		PosADC_INTSTAT = maskedStatus;
        return maskedStatus >> PosADC_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
