/*******************************************************************************
* File Name: PosFilter.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "PosFilter.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        PosFilter_PC =   (PosFilter_PC & \
                                (uint32)(~(uint32)(PosFilter_DRIVE_MODE_IND_MASK << (PosFilter_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (PosFilter_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: PosFilter_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void PosFilter_Write(uint8 value) 
{
    uint8 drVal = (uint8)(PosFilter_DR & (uint8)(~PosFilter_MASK));
    drVal = (drVal | ((uint8)(value << PosFilter_SHIFT) & PosFilter_MASK));
    PosFilter_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: PosFilter_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  PosFilter_DM_STRONG     Strong Drive 
*  PosFilter_DM_OD_HI      Open Drain, Drives High 
*  PosFilter_DM_OD_LO      Open Drain, Drives Low 
*  PosFilter_DM_RES_UP     Resistive Pull Up 
*  PosFilter_DM_RES_DWN    Resistive Pull Down 
*  PosFilter_DM_RES_UPDWN  Resistive Pull Up/Down 
*  PosFilter_DM_DIG_HIZ    High Impedance Digital 
*  PosFilter_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void PosFilter_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(PosFilter__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: PosFilter_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro PosFilter_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 PosFilter_Read(void) 
{
    return (uint8)((PosFilter_PS & PosFilter_MASK) >> PosFilter_SHIFT);
}


/*******************************************************************************
* Function Name: PosFilter_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 PosFilter_ReadDataReg(void) 
{
    return (uint8)((PosFilter_DR & PosFilter_MASK) >> PosFilter_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(PosFilter_INTSTAT) 

    /*******************************************************************************
    * Function Name: PosFilter_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 PosFilter_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(PosFilter_INTSTAT & PosFilter_MASK);
		PosFilter_INTSTAT = maskedStatus;
        return maskedStatus >> PosFilter_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
