/*******************************************************************************
* File Name: RefBuf22.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "RefBuf22.h"

#define SetP4PinDriveMode(shift, mode)  \
    do { \
        RefBuf22_PC =   (RefBuf22_PC & \
                                (uint32)(~(uint32)(RefBuf22_DRIVE_MODE_IND_MASK << (RefBuf22_DRIVE_MODE_BITS * (shift))))) | \
                                (uint32)((uint32)(mode) << (RefBuf22_DRIVE_MODE_BITS * (shift))); \
    } while (0)


/*******************************************************************************
* Function Name: RefBuf22_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void RefBuf22_Write(uint8 value) 
{
    uint8 drVal = (uint8)(RefBuf22_DR & (uint8)(~RefBuf22_MASK));
    drVal = (drVal | ((uint8)(value << RefBuf22_SHIFT) & RefBuf22_MASK));
    RefBuf22_DR = (uint32)drVal;
}


/*******************************************************************************
* Function Name: RefBuf22_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  RefBuf22_DM_STRONG     Strong Drive 
*  RefBuf22_DM_OD_HI      Open Drain, Drives High 
*  RefBuf22_DM_OD_LO      Open Drain, Drives Low 
*  RefBuf22_DM_RES_UP     Resistive Pull Up 
*  RefBuf22_DM_RES_DWN    Resistive Pull Down 
*  RefBuf22_DM_RES_UPDWN  Resistive Pull Up/Down 
*  RefBuf22_DM_DIG_HIZ    High Impedance Digital 
*  RefBuf22_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void RefBuf22_SetDriveMode(uint8 mode) 
{
	SetP4PinDriveMode(RefBuf22__0__SHIFT, mode);
}


/*******************************************************************************
* Function Name: RefBuf22_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro RefBuf22_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 RefBuf22_Read(void) 
{
    return (uint8)((RefBuf22_PS & RefBuf22_MASK) >> RefBuf22_SHIFT);
}


/*******************************************************************************
* Function Name: RefBuf22_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 RefBuf22_ReadDataReg(void) 
{
    return (uint8)((RefBuf22_DR & RefBuf22_MASK) >> RefBuf22_SHIFT);
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(RefBuf22_INTSTAT) 

    /*******************************************************************************
    * Function Name: RefBuf22_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 RefBuf22_ClearInterrupt(void) 
    {
		uint8 maskedStatus = (uint8)(RefBuf22_INTSTAT & RefBuf22_MASK);
		RefBuf22_INTSTAT = maskedStatus;
        return maskedStatus >> RefBuf22_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
