/*******************************************************************************
* File Name: RefDiff14.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "RefDiff14.h"

static RefDiff14_BACKUP_STRUCT  RefDiff14_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: RefDiff14_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function must be called for SIO and USBIO
*  pins. It is not essential if using GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet RefDiff14_SUT.c usage_RefDiff14_Sleep_Wakeup
*******************************************************************************/
void RefDiff14_Sleep(void)
{
    #if defined(RefDiff14__PC)
        RefDiff14_backup.pcState = RefDiff14_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            RefDiff14_backup.usbState = RefDiff14_CR1_REG;
            RefDiff14_USB_POWER_REG |= RefDiff14_USBIO_ENTER_SLEEP;
            RefDiff14_CR1_REG &= RefDiff14_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(RefDiff14__SIO)
        RefDiff14_backup.sioState = RefDiff14_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        RefDiff14_SIO_REG &= (uint32)(~RefDiff14_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: RefDiff14_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep().
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to RefDiff14_Sleep() for an example usage.
*******************************************************************************/
void RefDiff14_Wakeup(void)
{
    #if defined(RefDiff14__PC)
        RefDiff14_PC = RefDiff14_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            RefDiff14_USB_POWER_REG &= RefDiff14_USBIO_EXIT_SLEEP_PH1;
            RefDiff14_CR1_REG = RefDiff14_backup.usbState;
            RefDiff14_USB_POWER_REG &= RefDiff14_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(RefDiff14__SIO)
        RefDiff14_SIO_REG = RefDiff14_backup.sioState;
    #endif
}


/* [] END OF FILE */
