/* ========================================
 *
 * ========================================
*/
#include <I2Ccom.h>
#include <math.h>
#include <common.h>

void readBuffer(uint8_t addr, uint8_t reg, uint8 *I2CReadBuffer)
{
    uint8 I2CWriteBuffer[0x01] = {reg};
    
    // Do a write operation with the memory address bytes
	I2C_I2CMasterWriteBuf(addr, (uint8 *) I2CWriteBuffer, sizeof(I2CWriteBuffer), I2C_I2C_MODE_COMPLETE_XFER);
    while(!(I2C_I2CMasterStatus() & I2C_I2C_MSTAT_WR_CMPLT)); //Wait till the master completes writing
    I2C_I2CMasterClearStatus(); //Clear I2C master status
    
    // Read from the sensor and store it in a buffer */
	I2C_I2CMasterReadBuf(addr, (uint8 *) &I2CReadBuffer, sizeof(I2CReadBuffer), I2C_I2C_MODE_COMPLETE_XFER);
    while(!(I2C_I2CMasterStatus() & I2C_I2C_MSTAT_RD_CMPLT)); //Wait till the master completes reading
    I2C_I2CMasterClearStatus(); //Clear I2C master status

}

uint8_t read8(uint8_t addr, uint8_t reg)
{
    
    uint8 I2CWriteBuffer[0x01] = {reg};
    static uint8 I2CReadBuffer[0x01];
    
    // Do a write operation with the memory address bytes
	I2C_I2CMasterWriteBuf(addr, (uint8 *) I2CWriteBuffer, sizeof(I2CWriteBuffer), I2C_I2C_MODE_COMPLETE_XFER);
    while(!(I2C_I2CMasterStatus() & I2C_I2C_MSTAT_WR_CMPLT)); //Wait till the master completes writing
    I2C_I2CMasterClearStatus(); //Clear I2C master status
    
    // Read from the sensor and store it in a buffer */
	I2C_I2CMasterReadBuf(addr, (uint8 *) I2CReadBuffer, sizeof(I2CReadBuffer), I2C_I2C_MODE_COMPLETE_XFER);
    while(!(I2C_I2CMasterStatus() & I2C_I2C_MSTAT_RD_CMPLT)); //Wait till the master completes reading
    I2C_I2CMasterClearStatus(); //Clear I2C master status

    return I2CReadBuffer[0];
}

uint32_t read24(uint8_t addr, uint8_t reg)
{
    uint32_t x;
    
    uint8 I2CWriteBuffer[0x01] = {reg};
    static uint8 I2CReadBuffer[0x03];
    
    // Do a write operation with the memory address bytes */
	I2C_I2CMasterWriteBuf(addr, (uint8 *) I2CWriteBuffer, sizeof(I2CWriteBuffer), I2C_I2C_MODE_COMPLETE_XFER);
    while(!(I2C_I2CMasterStatus() & I2C_I2C_MSTAT_WR_CMPLT)); //Wait till the master completes writing
    I2C_I2CMasterClearStatus(); //Clear I2C master status
    
    // Read from the sensor and store it in a buffer */
	I2C_I2CMasterReadBuf(addr, (uint8 *) I2CReadBuffer, sizeof(I2CReadBuffer), I2C_I2C_MODE_COMPLETE_XFER);
    while(!(I2C_I2CMasterStatus() & I2C_I2C_MSTAT_RD_CMPLT)); //Wait till the master completes reading
    I2C_I2CMasterClearStatus(); //Clear I2C master status
    
    x = I2CReadBuffer[0];
    x <<= 8;
    x |= I2CReadBuffer[1];
    x <<= 8;
    x |= I2CReadBuffer[2];
    return x;
}

uint16_t read16(uint8_t addr, uint8_t reg)
{
  uint16_t x;
    
    uint8 I2CWriteBuffer[0x01] = {reg};
    static uint8 I2CReadBuffer[0x02];
    
    // Do a write operation with the memory address bytes */
	I2C_I2CMasterWriteBuf(addr, (uint8 *) I2CWriteBuffer, sizeof(I2CWriteBuffer), I2C_I2C_MODE_COMPLETE_XFER);
    while(!(I2C_I2CMasterStatus() & I2C_I2C_MSTAT_WR_CMPLT)); //Wait till the master completes writing
    I2C_I2CMasterClearStatus(); //Clear I2C master status
    
    // Read from the sensor and store it in a buffer */
	I2C_I2CMasterReadBuf(addr, (uint8 *) I2CReadBuffer, sizeof(I2CReadBuffer), I2C_I2C_MODE_COMPLETE_XFER);
    while(!(I2C_I2CMasterStatus() & I2C_I2C_MSTAT_RD_CMPLT)); //Wait till the master completes reading
    I2C_I2CMasterClearStatus(); //Clear I2C master status
    
    x = I2CReadBuffer[0];
    x <<= 8;
    x |= I2CReadBuffer[1];
    return x;
}

uint16_t read16_LE(uint8_t addr, uint8_t reg)
{
  uint16_t temp = read16(addr,reg);
  return (temp >> 8) | (temp << 8);
}

int16_t read16S(uint8_t addr, uint8_t reg)
{
 return (int16_t)read16(addr,reg);
}

int16_t read16S_LE(uint8_t addr, uint8_t reg)
{
  return (int16_t)read16_LE(addr,reg);
}

int8_t read8S(uint8_t addr, uint8_t reg)
{
    return (int8_t)read8(addr,reg);
}

void write8 (uint8_t addr, uint8_t reg, uint8_t value)
{
    // Create write buffer with register and input value
    uint8 I2CWriteBuffer[0x03] = {reg, value};
    
    // Do a write operation with the memory address bytes
	I2C_I2CMasterWriteBuf(addr, (uint8 *) I2CWriteBuffer, sizeof(I2CWriteBuffer), I2C_I2C_MODE_COMPLETE_XFER);
    while(!(I2C_I2CMasterStatus() & I2C_I2C_MSTAT_WR_CMPLT)); //Wait till the master completes writing
    I2C_I2CMasterClearStatus(); //Clear I2C master status
   
}

void write16 (uint8_t addr, uint8_t reg, uint16_t value)
{
    // Create write buffer with register and input value
    uint8 I2CWriteBuffer[0x03] = {reg, value};
    
    // Do a write operation with the memory address bytes
	I2C_I2CMasterWriteBuf(addr, (uint8 *) I2CWriteBuffer, sizeof(I2CWriteBuffer), I2C_I2C_MODE_COMPLETE_XFER);
    while(!(I2C_I2CMasterStatus() & I2C_I2C_MSTAT_WR_CMPLT)); //Wait till the master completes writing
    I2C_I2CMasterClearStatus(); //Clear I2C master status
   
}

// [] END OF FILE
