/* ========================================
  This is a library for the LSM9DS0 Accelerometer and magnentometer/compass
  These sensors use I2C to communicate, 2 pins are required to interface.
 *
 * ========================================
*/

//***************************************************************************
// CONSTRUCTOR
// ***************************************************************************/

#include "LSM9DS0.h"

boolean LSM9begin(void)
{
  uint8_t id = read8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_WHO_AM_I_XM);
  if (id != LSM9DS0_XM_ID)
    return FALSE;

  id = read8(LSM9DS0_ADDRESS_GYRO, LSM9DS0_REGISTER_WHO_AM_I_G);
  if (id != LSM9DS0_G_ID)
   return FALSE;

/*
  // Enable the accelerometer continous
  write8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_CTRL_REG1_XM, 0b01100111); // 100 Hz
  write8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_CTRL_REG5_XM, 0b10010100); // activate temperature reading, 100 Hz
  // enable mag continuous
  write8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_CTRL_REG7_XM, 0b00000010);
  // enable gyro continuous
  write8(LSM9DS0_ADDRESS_GYRO, LSM9DS0_REGISTER_CTRL_REG1_G, 0b00001111); // on XYZ
  // enable the temperature sensor (output rate same as the mag sensor)
  uint8_t tempReg = read8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_CTRL_REG5_XM);
  write8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_CTRL_REG5_XM, tempReg | (1<<7));
*/

//activate accelerometer and temperature
write8(LSM9DS0_ADDRESS_ACCELMAG >> 1,LSM9DS0_REGISTER_CTRL_REG1_XM,0B00110111);  
write8(LSM9DS0_ADDRESS_ACCELMAG >> 1,LSM9DS0_REGISTER_CTRL_REG5_XM,0B10001000);  //activate temp
write8(LSM9DS0_ADDRESS_ACCELMAG >> 1,LSM9DS0_REGISTER_CTRL_REG7_XM,0B00000000);  
//activate gyro
write8(LSM9DS0_ADDRESS_GYRO >> 1,LSM9DS0_REGISTER_CTRL_REG1_G,0B00001111);
CyDelay(10);

  // Set default ranges for the various sensors  
  //LSM9setupAccel(LSM9DS0_ACCELRANGE_2G);
  //LSM9setupMag(LSM9DS0_MAGGAIN_2GAUSS);
  //LSM9setupGyro(LSM9DS0_GYROSCALE_245DPS);

  return TRUE;
}

/***************************************************************************
 PUBLIC FUNCTIONS
 ***************************************************************************/
void LSM9read()
{
  /* Read all the sensors. */
  LSM9readAccel();
  LSM9readMag();
  LSM9readGyro();
  LSM9readTemp();
}

void LSM9readAccel()
{
    uint8_t buffer[6];
    /*
    readBuffer(LSM9DS0_ADDRESS_ACCELMAG, 0x80 | LSM9DS0_REGISTER_OUT_X_L_A, buffer);  

    uint8_t xlo = buffer[0];
    int16_t xhi = buffer[1];
    uint8_t ylo = buffer[2];
    int16_t yhi = buffer[3];
    uint8_t zlo = buffer[4];
    int16_t zhi = buffer[5];
    */
    
    uint8_t xlo = read8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_OUT_X_L_A);
    int16_t xhi = read8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_OUT_X_H_A);
    uint8_t ylo = read8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_OUT_Y_L_A);
    int16_t yhi = read8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_OUT_Y_H_A);
    uint8_t zlo = read8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_OUT_Z_L_A);
    int16_t zhi = read8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_OUT_Z_H_A);
  
    // Shift values to create properly formed integer (low byte first)
    xhi <<= 8; xhi |= xlo;
    yhi <<= 8; yhi |= ylo;
    zhi <<= 8; zhi |= zlo;
    accelData.x = xhi;
    accelData.y = yhi;
    accelData.z = zhi;
}

void LSM9readMag()
{
    uint8_t buffer[6];
    readBuffer(LSM9DS0_ADDRESS_ACCELMAG, 0x80 | LSM9DS0_REGISTER_OUT_X_L_M, buffer);
  
    uint8_t xlo = buffer[0];
    int16_t xhi = buffer[1];
    uint8_t ylo = buffer[2];
    int16_t yhi = buffer[3];
    uint8_t zlo = buffer[4];
    int16_t zhi = buffer[5];
  
    // Shift values to create properly formed integer (low byte first)
    xhi <<= 8; xhi |= xlo;
    yhi <<= 8; yhi |= ylo;
    zhi <<= 8; zhi |= zlo;
    
    magData.x = xhi;
    magData.y = yhi;
    magData.z = zhi;
}

void LSM9readGyro()
{
  uint8_t buffer[6];
  readBuffer(LSM9DS0_ADDRESS_GYRO, 0x80 | LSM9DS0_REGISTER_OUT_X_L_G, buffer);

  uint8_t xlo = buffer[0];
  int16_t xhi = buffer[1];
  uint8_t ylo = buffer[2];
  int16_t yhi = buffer[3];
  uint8_t zlo = buffer[4];
  int16_t zhi = buffer[5];
  
  // Shift values to create properly formed integer (low byte first)
  xhi <<= 8; xhi |= xlo;
  yhi <<= 8; yhi |= ylo;
  zhi <<= 8; zhi |= zlo;
  
  gyroData.x = xhi;
  gyroData.y = yhi;
  gyroData.z = zhi;
}

void LSM9readTemp()
{
    //uint8_t buffer[2];
    //int16_t xhi = read16S_LE(LSM9DS0_ADDRESS_ACCELMAG | 0b00000001, 0x80 | LSM9DS0_REGISTER_TEMP_OUT_L_XM);
    uint8_t xhi = read8((LSM9DS0_ADDRESS_ACCELMAG | 0x01)>>1, LSM9DS0_REGISTER_TEMP_OUT_H_XM);
    uint8_t xlo = read8((LSM9DS0_ADDRESS_ACCELMAG | 0x01)>>1, LSM9DS0_REGISTER_TEMP_OUT_L_XM);
    
    int16_t x = xhi << 8;
    x |= xlo;
    temperature = xhi;
}

void LSM9setupAccel ( lsm9ds0AccelRange_t range )
{
  uint8_t reg = read8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_CTRL_REG2_XM);
  reg &= ~(0b00111000);
  reg |= range;
  write8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_CTRL_REG2_XM, reg);
  
  switch (range)
  {
    case LSM9DS0_ACCELRANGE_2G:
      _accel_mg_lsb = LSM9DS0_ACCEL_MG_LSB_2G;
      break;
    case LSM9DS0_ACCELRANGE_4G:
      _accel_mg_lsb = LSM9DS0_ACCEL_MG_LSB_4G;
      break;
    case LSM9DS0_ACCELRANGE_6G:
      _accel_mg_lsb = LSM9DS0_ACCEL_MG_LSB_6G;
      break;
    case LSM9DS0_ACCELRANGE_8G:
      _accel_mg_lsb = LSM9DS0_ACCEL_MG_LSB_8G;
      break;    
    case LSM9DS0_ACCELRANGE_16G:
      _accel_mg_lsb =LSM9DS0_ACCEL_MG_LSB_16G;
      break;
  }
}

void LSM9setupMag ( lsm9ds0MagGain_t gain )
{
  uint8_t reg = read8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_CTRL_REG6_XM);
  reg &= ~(0b01100000);
  reg |= gain;
  write8(LSM9DS0_ADDRESS_ACCELMAG, LSM9DS0_REGISTER_CTRL_REG6_XM, reg );

  switch(gain)
  {
    case LSM9DS0_MAGGAIN_2GAUSS:
      _mag_mgauss_lsb = LSM9DS0_MAG_MGAUSS_2GAUSS;
      break;
    case LSM9DS0_MAGGAIN_4GAUSS:
      _mag_mgauss_lsb = LSM9DS0_MAG_MGAUSS_4GAUSS;
      break;
    case LSM9DS0_MAGGAIN_8GAUSS:
      _mag_mgauss_lsb = LSM9DS0_MAG_MGAUSS_8GAUSS;
      break;
    case LSM9DS0_MAGGAIN_12GAUSS:
      _mag_mgauss_lsb = LSM9DS0_MAG_MGAUSS_12GAUSS;
      break;
  }
}

void LSM9setupGyro ( lsm9ds0GyroScale_t scale )
{
  uint8_t reg = read8(LSM9DS0_ADDRESS_GYRO, LSM9DS0_REGISTER_CTRL_REG4_G);
  reg &= ~(0b00110000);
  reg |= scale;
  write8(LSM9DS0_ADDRESS_GYRO, LSM9DS0_REGISTER_CTRL_REG4_G, reg );

  switch(scale)
  {
    case LSM9DS0_GYROSCALE_245DPS:
      _gyro_dps_digit = LSM9DS0_GYRO_DPS_DIGIT_245DPS;
      break;
    case LSM9DS0_GYROSCALE_500DPS:
      _gyro_dps_digit = LSM9DS0_GYRO_DPS_DIGIT_500DPS;
      break;
    case LSM9DS0_GYROSCALE_2000DPS:
      _gyro_dps_digit = LSM9DS0_GYRO_DPS_DIGIT_2000DPS;
      break;
  }
}

/***************************************************************************
 PRIVATE FUNCTIONS
 ***************************************************************************/

/* [] END OF FILE */
