/******************************************************************************
* Project Name		: Blinking LED
*******************************************************************************/

#include <device.h>
#include <stdio.h>
#include <math.h>
#include <common.h>
#include <project.h>
#include "define.h"
#include "BME280.h"
//#include "BMP180.h"
//#include "HTU21D.h"
//#include "MCP23017.h"
//#include "LCD.h"
#include "BLEApplications.h"
//#include "MCPdac.h"
//#include "LSM9DS0.h"
#include "LSM9.h"
#include "EasySleep.h"
#include <cytypes.h>

#define WDT_2SEC                            (65534u)
#define WDT_1SEC                            (32767u)
#define WDT_500MSEC                         (16383u)
#define WDT_250MSEC                         (8191u)
#define WDT_100MSEC                         (3277u)

CY_ISR_PROTO(SleepWakeHandler);

#define ENABLE_LOW_POWER_MODE
#define ENABLE_LED_NOTIFICATION
#define ACTIVE      (0u)
#define SLEEP       (1u)
#define DEEPSLEEP   (2u)

CYBLE_API_RESULT_T apiResult;
CYBLE_GATT_HANDLE_VALUE_PAIR_T measurementHandle;
uint8 counter = 1;

char timeBuffer[16u];
char dateBuffer[16u];
char tempBuffer[32u];
char pressureBuffer[16u];
boolean sensorFlag = 0;

union byteFloat
{
    byte array[4];
    float value;
};

void HandleLowPowerMode(uint8 lpmSel);
void UpdateConnectionParam(void);
uint8 LPMselData;

static CYBLE_GAP_CONN_UPDATE_PARAM_T ConnectionParam =
{
    CONN_PARAM_UPDATE_MIN_CONN_INTERVAL,  		      
    CONN_PARAM_UPDATE_MAX_CONN_INTERVAL,		       
    CONN_PARAM_UPDATE_SLAVE_LATENCY,			    
    CONN_PARAM_UPDATE_SUPRV_TIMEOUT 			         	
};

void WDT_Start()
{
    CySysWdtUnlock();
    SleepWake_StartEx(&SleepWakeHandler);
    CyGlobalIntEnable;
    CySysWdtSetMode(CY_SYS_WDT_COUNTER0, CY_SYS_WDT_MODE_INT);
    CySysWdtSetMatch(CY_SYS_WDT_COUNTER0, WDT_1SEC);
    CySysWdtSetClearOnMatch(CY_SYS_WDT_COUNTER0, TRUE);
    CySysWdtResetCounters(CY_SYS_WDT_COUNTER0);
    CySysWdtDisable(CY_SYS_WDT_COUNTER0_MASK);
    SleepWake_Enable();
    //CySysWdtLock();
}
   
int main()
{
    I2C_Start();
    Buffer1_Start();
    PosBias_Start();
    NegBias_Start();
    DAC_Start();
    UART_Start();
    ADC_Start();
    CyBle_Start(CustomEventHandler);
    WDT_Start();
    CySysClkWriteEcoDiv(CY_SYS_CLK_ECO_DIV8);
    
    LSM9(0x6B,0x1D);
    uint16_t whoIam = begin(G_SCALE_245DPS, A_SCALE_2G, M_SCALE_2GS, G_ODR_95_BW_125, A_ODR_50, M_ODR_50);
    
    sprintf(tempBuffer, "Who I am result: %x \n", whoIam);
    UART_UartPutString(tempBuffer);
    UART_UartPutString("Result should be 0x49D4 \n");
        
    apiResult = CyBle_Start(CustomEventHandler);
    //CyBle_BasRegisterAttrCallback(BasCallBack);
    //CyBle_HtsRegisterAttrCallback(HtsCallBack);
    int bmeStatus = BME280_begin();
    if (bmeStatus == 1)
        UART_UartPutString("Environmental Sensor Configured \n");
    
    DAC_SetValue(0);
    LCLK_Write(HIGH);
    LCSB_Write(HIGH);
    GreenLED_Write(HIGH);
    
    while (CyBle_GetState() == CYBLE_STATE_INITIALIZING)
    {
        CyBle_ProcessEvents(); 
    }

    // MAIN CODE TEXT
	while(1)
    {
        CyBle_ProcessEvents();
       
        if (CyBle_GetState() == CYBLE_STATE_ADVERTISING)
        {
            while(1)
            {
                CyBle_ProcessEvents();
                CyDelay(100);
                LCLK_Write(0);
                CyDelay(100);
                LCLK_Write(1);
                UART_UartPutString("Advertising... \n");
                if (CyBle_GetState() == CYBLE_STATE_CONNECTED)
                {
                    break;
                }
            }
            UART_UartPutString("\n");
            int i = 1;
            while (i<5000) // 5s delay to allow services and characteristics to be read
            {
                CyDelay(1);
                CyBle_ProcessEvents();
                i++;
            }
            
            CySysWdtEnable(CY_SYS_WDT_COUNTER0_MASK);
            //UpdateConnectionParam();
            
        }
        
        if (CyBle_GetState() == CYBLE_STATE_CONNECTED)
        {
            //UpdateConnectionParam();
            //CyBle_ProcessEvents();
            //LowPowerImplementation();
            //CyBle_ProcessEvents();
            //CySysPmSleep();
        }

        HandleLowPowerMode(DEEPSLEEP);
        //sleep_ble(BLE_SLEEP_CPU_SLEEP);
        LCSB_Write(HIGH);
        LCLK_Write(HIGH);
        GreenLED_Write(HIGH);
        
        if (sensorFlag == TRUE)
        {
            //LSM9read();
            //ReadAndCalculateSensorData();
            LCLK_Write(LOW);
            
            ADC_StartConvert();
            ADC_IsEndConversion(ADC_WAIT_FOR_RESULT);
            CyDelay(15);
            int adcValue1 = 0;
            int adcValue2 = 0;
        
            adcValue1 = ADC_GetResult16(0);
            adcValue2 = ADC_GetResult16(1);
            ADC_StopConvert();
            ADC_CountsTo_mVolts(0,adcValue1);
            ADC_CountsTo_mVolts(1,adcValue2);
        
            sprintf(tempBuffer, "%03u ADC1 Value", adcValue1);
            UART_UartPutString(tempBuffer);
            UART_UartPutString("\n");
            sprintf(tempBuffer, "%03u ADC2 Value", adcValue2);
            UART_UartPutString(tempBuffer);
            UART_UartPutString("\n");
       
            uint8 RSSI = CyBle_GetRssi();
            //CyBle_SetPowerLevel();
            sprintf(tempBuffer, "%u BLE RSSI     ", RSSI);
            UART_UartPutString(tempBuffer);
            UART_UartPutString("\n");
        
            readGyro();
	        readAccel();
	        readMag();
            sprintf(tempBuffer, "M X: %0.2hd / Y: %0.2hd / Z: %0.2hd", mx, my, mz);
            UART_UartPutString(tempBuffer);
            UART_UartPutString("\n");
            sprintf(tempBuffer, "A X: %0.2hd / Y: %0.2hd / Z: %0.2hd", ax, ay, az);
            UART_UartPutString(tempBuffer);
            UART_UartPutString("\n");
            sprintf(tempBuffer, "G X: %0.2hd / Y: %0.2hd / Z: %0.2hd", gx, gy, gz);
            UART_UartPutString(tempBuffer);
            UART_UartPutString("\n");
            UART_UartPutString("A \n");
    
            
            float rhTemperature = readTemperature();
            //long Temperature = ReturnTemperature();
            float Humidity = readHumidity();
            //float Humidity = readHumidityHTU();
            float Pressure = readPressure();
            //long Pressure = ReturnPressure();
        
            readTemp();
            sprintf(tempBuffer, "%03u Degrees X", temperature);
            UART_UartPutString(tempBuffer);
            UART_UartPutString("\n");
            //sprintf(tempBuffer, "%0.2f Degrees", Temperature);
            //UART_UartPutString(tempBuffer);
            //UART_UartPutString("\n");
            sprintf(pressureBuffer, "%0.2f Pascal", Pressure);
            UART_UartPutString(pressureBuffer);
            UART_UartPutString("\n");
        
            sprintf(tempBuffer, "%0.2f %%RH", Humidity);
            UART_UartPutString(tempBuffer);
            UART_UartPutString("\n");
            sprintf(tempBuffer, "%0.2f Degrees", rhTemperature);
            UART_UartPutString(tempBuffer);
            UART_UartPutString("\n");
            UART_UartPutString("\n");
        
            uint8 pressureData[2];
            pressureData[0] = adcValue1 >> 8;
            pressureData[1] = adcValue1 & 0xFF;
            measurementHandle.attrHandle = MEASUREMENT_CHAR_HANDLE;
	        measurementHandle.value.val = pressureData;
	        measurementHandle.value.len = sizeof(pressureData);
	        measurementHandle.value.actualLen = sizeof(pressureData);
            
            // Send updated pressure reading handle as attribute for read by central device
	        CyBle_GattsWriteAttributeValue(&measurementHandle, FALSE, &cyBle_connHandle, FALSE);
            CyBle_GattsNotification(cyBle_connHandle, &measurementHandle);
            
            union byteFloat humidityBuffer;
            humidityBuffer.value = Humidity;
            measurementHandle.attrHandle = RX_CHAR_HANDLE;
            measurementHandle.value.val = humidityBuffer.array;
            measurementHandle.value.len = sizeof(humidityBuffer.array);
            measurementHandle.value.actualLen = sizeof(humidityBuffer.array);
	
            // Send updated pressure reading handle as attribute for read by central device
	        CyBle_GattsWriteAttributeValue(&measurementHandle, FALSE, &cyBle_connHandle, FALSE);
            CyBle_GattsNotification(cyBle_connHandle, &measurementHandle);
        
            sensorFlag = FALSE;
            DAC_SetValue(counter);
            LCLK_Write(HIGH);
        }
    }
}

CY_ISR(SleepWakeHandler)
{
    if (CySysWdtGetInterruptSource() & CY_SYS_WDT_COUNTER0_INT)
    {
        if (counter%4 == 0)
            sensorFlag = TRUE;
        
        if (counter > 255)
            counter = 0;
            
        counter++;
        
        /* Clear interrupts state */
    	CySysWdtClearInterrupt(CY_SYS_WDT_COUNTER0_INT);
        SleepWake_ClearPending();
    }
    
}

/*******************************************************************************
* Function Name: HandleLowPowerMode
********************************************************************************
* Summary:
*        This function puts the BLESS in deep sleep mode and CPU to sleep mode. 
* System will resume from here when it wakes from user button press.
*******************************************************************************/
void HandleLowPowerMode(uint8 lpmSel)
{
	CYBLE_LP_MODE_T sleepMode;
	CYBLE_BLESS_STATE_T blessState;
    uint32_t interruptStatus;
    
    if (lpmSel == DEEPSLEEP)
    {
        sleepMode = CyBle_EnterLPM(CYBLE_BLESS_DEEPSLEEP);
		blessState = CyBle_GetBleSsState();
        interruptStatus = CyEnterCriticalSection();

		if(sleepMode == CYBLE_BLESS_DEEPSLEEP)
		{
			if(blessState == CYBLE_BLESS_STATE_ECO_ON || blessState == CYBLE_BLESS_STATE_DEEPSLEEP)
		    {
                LCLK_Write(LOW);
                UART_UartPutString("Entering Deep Sleep...");
                UART_UartPutString("\n");
                CyDelay(10);
		        CySysPmDeepSleep();
		 	}
        }
        else if (blessState != CYBLE_BLESS_STATE_EVENT_CLOSE)
        {
            UART_UartPutString("Entering Sleep...");
            UART_UartPutString("\n");
            CyDelay(10);
            CySysClkWriteHfclkDirect(CY_SYS_CLK_HFCLK_ECO);
            CySysClkImoStop();
            CySysPmSleep();
            CySysClkImoStart();
            CySysClkWriteHfclkDirect(CY_SYS_CLK_HFCLK_IMO);
        }
        else
        {}
        
        CyExitCriticalSection(interruptStatus);
    }
    
    else if (lpmSel == SLEEP)
    {
        interruptStatus = CyEnterCriticalSection();
		sleepMode = CyBle_EnterLPM(CYBLE_BLESS_SLEEP);
		blessState = CyBle_GetBleSsState();

		if(sleepMode == CYBLE_BLESS_SLEEP)
		{
		    if(blessState != CYBLE_BLESS_STATE_EVENT_CLOSE)
		    {
                UART_UartPutString("Entering Sleep...");
                UART_UartPutString("\n");
                CyDelay(10);
		        CySysPmSleep();
                LCSB_Write(LOW);
		    }
		}
		
		/* Re-enable global interrupt mask after wakeup */
		//CyGlobalIntEnable;
        CyExitCriticalSection(interruptStatus);
    }
    else if (lpmSel == ACTIVE)
    {
        /* Leave chip in Active mode */
        #ifdef ENABLE_LED_NOTIFICATION
        GreenLED_Write(0);
        #endif
    }
    else{}
}

void UpdateConnectionParam(void)
{
	/* If device is connected and Update connection parameter not updated yet,
	* then send the Connection Parameter Update request to Client. */
    if(deviceConnected && isConnectionUpdateRequested)
	{
		/* Reset the flag to indicate that connection Update request has been sent */
		isConnectionUpdateRequested = FALSE;
		
		/* Send Connection Update request with set Parameter */
		CyBle_L2capLeConnectionParamUpdateRequest(cyBle_connHandle.bdHandle, &ConnectionParam);
	}
}

/* [] END OF FILE */
